@@ -125,10 +125,14 @@
     growthForm <- paste0(growthForm, nextPhase)
   }
   tryCatch(
-    expr = { growthForm <- stats::as.formula(growthForm) },
+    expr = {
+      growthForm <- stats::as.formula(growthForm)
+    },
     error = function(err) {
-      message(paste0("Error while assembling changepoint formula, did you specify priors for ",
-                     paste(params, collapse = ", "), "? Changepoint priors must be named."))
+      message(paste0(
+        "Error while assembling changepoint formula, did you specify priors for ",
+        paste(params, collapse = ", "), "? Changepoint priors must be named."
+      ))
       message("The original Error message is:")
       stop(conditionMessage(err))
     }
@@ -159,7 +163,7 @@
 .handleSplineSegments <- function(splineSegments, useGroup, group, nTimes, formulae, x) {
   if (length(splineSegments) > 0) {
     if (useGroup) {
-      by <- paste0(", by = ", group)
+      by <- paste0(", by = ", paste(group, collapse = ":"))
     } else {
       by <- ","
     }
