@@ -2,7 +2,8 @@
 #'
 #' @param ss A list output from \link{growthSS}. This is not required for nls, nlme, and brms models
 #' if \code{test} is given in \code{brms::hypothesis} style as a written statement.
-#' @param fit A model (or list of nlrq models) output from \link{fitGrowth}.
+#' @param fit A model (or list of nlrq models) output from \link{fitGrowth}. For brms models this
+#' can also be a data.frame of draws.
 #' @param test A description of the hypothesis to test. This can take two main forms,
 #' either the parameter names to vary before comparing a nested model ("A", "B", "C") using an anova
 #' or a hypothesis test/list of hypothesis tests written as character strings.
@@ -25,7 +26,8 @@
 #' @importFrom methods is
 #' @importFrom car deltaMethod
 #' @importFrom survival survdiff
-#'
+#' @seealso \link{growthSS} and \link{fitGrowth} for making compatible models, \link{growthPlot}
+#' for hypothesis testing on compatible models.
 #' @details
 #' For nls and nlme models an anova is run and returned as part of a list along with the null model.
 #'  For nlrq models several assumptions are made and a likelihood ratio test for each tau
@@ -114,12 +116,12 @@ testGrowth <- function(ss = NULL, fit, test = "A") {
 #' @examples
 #'
 #' logistic_df <- growthSim("logistic",
-#'  n = 20, t = 25,
-#'  params = list("A" = c(200, 160), "B" = c(13, 11), "C" = c(3, 3.5))
+#'   n = 20, t = 25,
+#'   params = list("A" = c(200, 160), "B" = c(13, 11), "C" = c(3, 3.5))
 #' )
 #' ss <- growthSS(
-#'  model = "logistic", form = y ~ time | id / group,
-#'  df = logistic_df, type = "nls"
+#'   model = "logistic", form = y ~ time | id / group,
+#'   df = logistic_df, type = "nls"
 #' )
 #' fit <- fitGrowth(ss)
 #' .nlhypothesis(fit, test = list("A1 - A2", "B1-B2"))
@@ -134,7 +136,7 @@ testGrowth <- function(ss = NULL, fit, test = "A") {
     coefs <- nlme::fixef(fit)
   } else if (methods::is(fit, "nls")) {
     coefs <- stats::coef(fit)
-  } else if (methods::is(fit, "brmsfit")) {
+  } else if (methods::is(fit, "brmsfit") || methods::is(fit, "data.frame")) {
     out <- brms::hypothesis(fit, test)
     return(out)
   } else if (methods::is(fit, "nlrq") || is.list(fit)) {
@@ -168,12 +170,12 @@ testGrowth <- function(ss = NULL, fit, test = "A") {
 #' @examples
 #'
 #' logistic_df <- growthSim("logistic",
-#'  n = 20, t = 25,
-#'  params = list("A" = c(200, 160), "B" = c(13, 11), "C" = c(3, 3.5))
+#'   n = 20, t = 25,
+#'   params = list("A" = c(200, 160), "B" = c(13, 11), "C" = c(3, 3.5))
 #' )
 #' ss <- growthSS(
-#'  model = "gam", form = y ~ time | id / group,
-#'  df = logistic_df, type = "mgcv"
+#'   model = "gam", form = y ~ time | id / group,
+#'   df = logistic_df, type = "mgcv"
 #' )
 #' fit <- fitGrowth(ss)
 #' .mgcvGamAnova(ss, fit)$anova
@@ -202,13 +204,13 @@ testGrowth <- function(ss = NULL, fit, test = "A") {
 #' @examples
 #'
 #' logistic_df <- growthSim("logistic",
-#'  n = 20, t = 25,
-#'  params = list("A" = c(200, 160), "B" = c(13, 11), "C" = c(3, 3.5))
+#'   n = 20, t = 25,
+#'   params = list("A" = c(200, 160), "B" = c(13, 11), "C" = c(3, 3.5))
 #' )
 #' ss <- growthSS(
-#'  model = "gam", form = y ~ time | id / group,
-#'  df = logistic_df, type = "nlme"
-#'  )
+#'   model = "gam", form = y ~ time | id / group,
+#'   df = logistic_df, type = "nlme"
+#' )
 #' fit <- fitGrowth(ss)
 #' .lmeGamAnova(ss, fit)$anova
 #'
@@ -248,12 +250,12 @@ testGrowth <- function(ss = NULL, fit, test = "A") {
 #' @examples
 #'
 #' logistic_df <- growthSim("logistic",
-#'  n = 20, t = 25,
-#'  params = list("A" = c(200, 160), "B" = c(13, 11), "C" = c(3, 3.5))
+#'   n = 20, t = 25,
+#'   params = list("A" = c(200, 160), "B" = c(13, 11), "C" = c(3, 3.5))
 #' )
 #' ss <- growthSS(
-#'  model = "gam", form = y ~ time | id / group,
-#'  df = logistic_df, type = "nlrq", tau = c(0.25, 0.5, 0.75)
+#'   model = "gam", form = y ~ time | id / group,
+#'   df = logistic_df, type = "nlrq", tau = c(0.25, 0.5, 0.75)
 #' )
 #' fit <- fitGrowth(ss, cores = 3)
 #' .rqGamAnova(ss, fit)$"0.25"$anova
@@ -296,12 +298,12 @@ testGrowth <- function(ss = NULL, fit, test = "A") {
 #' @examples
 #'
 #' logistic_df <- growthSim("logistic",
-#'  n = 20, t = 25,
-#'  params = list("A" = c(200, 160), "B" = c(13, 11), "C" = c(3, 3.5))
+#'   n = 20, t = 25,
+#'   params = list("A" = c(200, 160), "B" = c(13, 11), "C" = c(3, 3.5))
 #' )
 #' ss <- growthSS(
-#'  model = "gam", form = y ~ time | id / group,
-#'  df = logistic_df, type = "nls"
+#'   model = "gam", form = y ~ time | id / group,
+#'   df = logistic_df, type = "nls"
 #' )
 #' fit <- fitGrowth(ss)
 #' .lmGamAnova(ss, fit)$anova
@@ -330,18 +332,18 @@ testGrowth <- function(ss = NULL, fit, test = "A") {
 #' @examples
 #'
 #' logistic_df <- growthSim("logistic",
-#'  n = 20, t = 25,
-#'  params = list("A" = c(200, 160), "B" = c(13, 11), "C" = c(3, 3.5))
+#'   n = 20, t = 25,
+#'   params = list("A" = c(200, 160), "B" = c(13, 11), "C" = c(3, 3.5))
 #' )
 #' ss <- growthSS(
-#'  model = "logistic", form = y ~ time | id / group,
-#'  df = logistic_df, type = "nls"
+#'   model = "logistic", form = y ~ time | id / group,
+#'   df = logistic_df, type = "nls"
 #' )
 #' fit <- fitGrowth(ss)
 #' .nlsAnova(ss, fit, test_pars = "A")$anova
 #' ss <- growthSS(
-#'  model = "logistic", form = y ~ time | id / group,
-#'  df = logistic_df, type = "nlme"
+#'   model = "logistic", form = y ~ time | id / group,
+#'   df = logistic_df, type = "nlme"
 #' )
 #' fit <- fitGrowth(ss)
 #' .nlsAnova(ss, fit, test_pars = "A")$anova
@@ -373,12 +375,12 @@ testGrowth <- function(ss = NULL, fit, test = "A") {
 #' @examples
 #'
 #' logistic_df <- growthSim("logistic",
-#'  n = 20, t = 25,
-#'  params = list("A" = c(200, 160), "B" = c(13, 11), "C" = c(3, 3.5))
+#'   n = 20, t = 25,
+#'   params = list("A" = c(200, 160), "B" = c(13, 11), "C" = c(3, 3.5))
 #' )
 #' ss <- growthSS(
-#'  model = "logistic", form = y ~ time | id / group,
-#'  df = logistic_df, type = "nlrq", tau = c(0.25, 0.5, 0.75)
+#'   model = "logistic", form = y ~ time | id / group,
+#'   df = logistic_df, type = "nlrq", tau = c(0.25, 0.5, 0.75)
 #' )
 #' fit <- fitGrowth(ss)
 #' .nlrqTest(ss, fit, test_pars = "A")$anova
@@ -451,12 +453,12 @@ testGrowth <- function(ss = NULL, fit, test = "A") {
 #' Parameterized test for nlrq models using SE
 #' @examples
 #' logistic_df <- growthSim("logistic",
-#'  n = 20, t = 25,
-#'  params = list("A" = c(200, 160), "B" = c(13, 11), "C" = c(3, 3.5))
+#'   n = 20, t = 25,
+#'   params = list("A" = c(200, 160), "B" = c(13, 11), "C" = c(3, 3.5))
 #' )
 #' ss <- growthSS(
-#'  model = "logistic", form = y ~ time | id / group,
-#'  df = logistic_df, type = "nlrq", tau = c(0.25, 0.5, 0.75)
+#'   model = "logistic", form = y ~ time | id / group,
+#'   df = logistic_df, type = "nlrq", tau = c(0.25, 0.5, 0.75)
 #' )
 #' fit <- fitGrowth(ss)
 #' .nlrqTest2(ss, fit, test_pars = "a|0.5|A > b|0.5|A")
@@ -528,8 +530,8 @@ testGrowth <- function(ss = NULL, fit, test = "A") {
 #'
 #'
 #' df <- growthSim("logistic",
-#'  n = 20, t = 25,
-#'  params = list("A" = c(200, 160), "B" = c(13, 11), "C" = c(3, 3.5))
+#'   n = 20, t = 25,
+#'   params = list("A" = c(200, 160), "B" = c(13, 11), "C" = c(3, 3.5))
 #' )
 #' ss <- growthSS("survival weibull", y > 100 ~ time | id / group, df = df, type = "survreg")
 #' fit <- fitGrowth(ss)
